import { Order } from 'Order';
import { OrdersRequestBody } from 'ManagerRequests'
import Axios, { AxiosError } from 'axios'
import { sleep } from 'utils'

const URL = (process.env.REACT_APP_BACKEND_URL as string)

const BASE_PATH = `${URL}/api/orders`

export const allOrders = () => {
    return fetch(`${BASE_PATH}/`).then((response) => response.json())
}

export const orderById = (apiUrl: string) => {
    return fetch(apiUrl).then((response) => response.json())
}

export const orders = async (body: OrdersRequestBody): Promise<Order[]> => {
    try {
        const response = await Axios.post(`${BASE_PATH}/filtered`, body)
        await sleep(400)
        return response.data;
    } catch (error) {
        error as AxiosError;
        console.error('`OrderService#orders` FAILED TO FETCH ORDERS: ', error)
        return [];
    }
}

export default {
    allOrders,
    orderById,
    orders
}